package org.jeecg.modules.userLogin.controller;

import java.util.Arrays;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.modules.userLogin.entity.UserLogin;
import org.jeecg.modules.userLogin.service.IUserLoginService;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: user_login
 * @Author: jeecg-boot
 * @Date:   2025-01-21
 * @Version: V1.0
 */
@Tag(name="user_login")
@RestController
@RequestMapping("/userLogin/userLogin")
@Slf4j
public class UserLoginController extends JeecgController<UserLogin, IUserLoginService> {
	@Autowired
	private IUserLoginService userLoginService;
	
	/**
	 * 分页列表查询
	 *
	 * @param userLogin
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "user_login-分页列表查询")
	@Operation(summary="user_login-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<UserLogin>> queryPageList(UserLogin userLogin,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<UserLogin> queryWrapper = QueryGenerator.initQueryWrapper(userLogin, req.getParameterMap());
		Page<UserLogin> page = new Page<UserLogin>(pageNo, pageSize);
		IPage<UserLogin> pageList = userLoginService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param userLogin
	 * @return
	 */
	@AutoLog(value = "user_login-添加")
	@Operation(summary="user_login-添加")
	@RequiresPermissions("userLogin:user_login:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody UserLogin userLogin) {
		userLoginService.save(userLogin);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param userLogin
	 * @return
	 */
	@AutoLog(value = "user_login-编辑")
	@Operation(summary="user_login-编辑")
	@RequiresPermissions("userLogin:user_login:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody UserLogin userLogin) {
		userLoginService.updateById(userLogin);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "user_login-通过id删除")
	@Operation(summary="user_login-通过id删除")
	@RequiresPermissions("userLogin:user_login:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		userLoginService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "user_login-批量删除")
	@Operation(summary="user_login-批量删除")
	@RequiresPermissions("userLogin:user_login:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.userLoginService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "user_login-通过id查询")
	@Operation(summary="user_login-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<UserLogin> queryById(@RequestParam(name="id",required=true) String id) {
		UserLogin userLogin = userLoginService.getById(id);
		if(userLogin==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(userLogin);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param userLogin
    */
    @RequiresPermissions("userLogin:user_login:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, UserLogin userLogin) {
        return super.exportXls(request, userLogin, UserLogin.class, "user_login");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("userLogin:user_login:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, UserLogin.class);
    }

}
